@@ -11,6 +11,7 @@
  ****************************************************************************/
 
 #include "gdal_frmts.h"
+#include "gdal_priv.h"
 #include "ogr_spatialref.h"
 #include "rawdataset.h"
 
@@ -87,6 +88,8 @@ class ISCERasterBand final : public RawRasterBand
     ISCERasterBand(GDALDataset *poDS, int nBand, VSILFILE *fpRaw,
                    vsi_l_offset nImgOffset, int nPixelOffset, int nLineOffset,
                    GDALDataType eDataType, int bNativeOrder);
+
+    ~ISCERasterBand() override;
 };
 
 /************************************************************************/
@@ -106,6 +109,7 @@ static CPLString getXMLFilename(GDALOpenInfo *poOpenInfo)
         osXMLFilename =
             CPLFormFilenameSafe(nullptr, poOpenInfo->pszFilename, "xml");
         VSIStatBufL psXMLStatBuf;
+        CPLErrorStateBackuper oBackuper(CPLQuietErrorHandler);
         if (VSIStatL(osXMLFilename, &psXMLStatBuf) != 0)
         {
             osXMLFilename = "";
@@ -288,7 +292,6 @@ CPLErr ISCEDataset::FlushCache(bool bAtClosing)
     /*      georeferencing.                                                 */
     /* -------------------------------------------------------------------- */
     CPLXMLNode *psCoordinate1Node, *psCoordinate2Node;
-    double adfGeoTransform[6];
 
     /* Coordinate 1 */
     psCoordinate1Node = CPLCreateXMLNode(psDocNode, CXT_Element, "component");
@@ -334,9 +337,10 @@ CPLErr ISCEDataset::FlushCache(bool bAtClosing)
     CPLAddXMLAttributeAndValue(psTmpNode, "name", "size");
     CPLCreateXMLElementAndValue(psTmpNode, "value", sBuf);
 
-    if (GetGeoTransform(adfGeoTransform) == CE_None)
+    GDALGeoTransform gt;
+    if (GetGeoTransform(gt) == CE_None)
     {
-        if (adfGeoTransform[2] != 0 || adfGeoTransform[4] != 0)
+        if (gt[2] != 0 || gt[4] != 0)
         {
             CPLError(CE_Warning, CPLE_AppDefined,
                      "ISCE format do not support geotransform with "
@@ -344,25 +348,25 @@ CPLErr ISCEDataset::FlushCache(bool bAtClosing)
         }
         else
         {
-            CPLsnprintf(sBuf, sizeof(sBuf), "%g", adfGeoTransform[0]);
+            CPLsnprintf(sBuf, sizeof(sBuf), "%g", gt[0]);
             psTmpNode =
                 CPLCreateXMLNode(psCoordinate1Node, CXT_Element, "property");
             CPLAddXMLAttributeAndValue(psTmpNode, "name", "startingValue");
             CPLCreateXMLElementAndValue(psTmpNode, "value", sBuf);
 
-            CPLsnprintf(sBuf, sizeof(sBuf), "%g", adfGeoTransform[1]);
+            CPLsnprintf(sBuf, sizeof(sBuf), "%g", gt[1]);
             psTmpNode =
                 CPLCreateXMLNode(psCoordinate1Node, CXT_Element, "property");
             CPLAddXMLAttributeAndValue(psTmpNode, "name", "delta");
             CPLCreateXMLElementAndValue(psTmpNode, "value", sBuf);
 
-            CPLsnprintf(sBuf, sizeof(sBuf), "%g", adfGeoTransform[3]);
+            CPLsnprintf(sBuf, sizeof(sBuf), "%g", gt[3]);
             psTmpNode =
                 CPLCreateXMLNode(psCoordinate2Node, CXT_Element, "property");
             CPLAddXMLAttributeAndValue(psTmpNode, "name", "startingValue");
             CPLCreateXMLElementAndValue(psTmpNode, "value", sBuf);
 
-            CPLsnprintf(sBuf, sizeof(sBuf), "%g", adfGeoTransform[5]);
+            CPLsnprintf(sBuf, sizeof(sBuf), "%g", gt[5]);
             psTmpNode =
                 CPLCreateXMLNode(psCoordinate2Node, CXT_Element, "property");
             CPLAddXMLAttributeAndValue(psTmpNode, "name", "delta");
@@ -405,6 +409,10 @@ char **ISCEDataset::GetFileList()
 
 int ISCEDataset::Identify(GDALOpenInfo *poOpenInfo)
 {
+    if (!poOpenInfo->IsSingleAllowedDriver("ISCE") &&
+        poOpenInfo->IsExtensionEqualToCI("zarr"))
+        return false;
+
     /* -------------------------------------------------------------------- */
     /*      TODO: This function is unusable now:                            */
     /*          * we can't just check for the presence of a XML file        */
@@ -686,18 +694,14 @@ GDALDataset *ISCEDataset::Open(GDALOpenInfo *poOpenInfo, bool bFileSizeCheck)
         aosXmlProps.FetchNameValue("Coordinate2startingValue") != nullptr &&
         aosXmlProps.FetchNameValue("Coordinate2delta") != nullptr)
     {
-        double adfGeoTransform[6];
-        adfGeoTransform[0] =
-            CPLAtof(aosXmlProps.FetchNameValue("Coordinate1startingValue"));
-        adfGeoTransform[1] =
-            CPLAtof(aosXmlProps.FetchNameValue("Coordinate1delta"));
-        adfGeoTransform[2] = 0.0;
-        adfGeoTransform[3] =
-            CPLAtof(aosXmlProps.FetchNameValue("Coordinate2startingValue"));
-        adfGeoTransform[4] = 0.0;
-        adfGeoTransform[5] =
-            CPLAtof(aosXmlProps.FetchNameValue("Coordinate2delta"));
-        poDS->SetGeoTransform(adfGeoTransform);
+        GDALGeoTransform gt;
+        gt[0] = CPLAtof(aosXmlProps.FetchNameValue("Coordinate1startingValue"));
+        gt[1] = CPLAtof(aosXmlProps.FetchNameValue("Coordinate1delta"));
+        gt[2] = 0.0;
+        gt[3] = CPLAtof(aosXmlProps.FetchNameValue("Coordinate2startingValue"));
+        gt[4] = 0.0;
+        gt[5] = CPLAtof(aosXmlProps.FetchNameValue("Coordinate2delta"));
+        poDS->SetGeoTransform(gt);
 
         /* ISCE format seems not to have a projection field, but uses   */
         /* WGS84.                                                       */
@@ -839,6 +843,8 @@ ISCERasterBand::ISCERasterBand(GDALDataset *poDSIn, int nBandIn,
 {
 }
 
+ISCERasterBand::~ISCERasterBand() = default;
+
 /************************************************************************/
 /*                         GDALRegister_ISCE()                          */
 /************************************************************************/
