@@ -19,10 +19,6 @@
 #include <cstdlib>
 #include <cstring>
 
-#if HAVE_FCNTL_H
-#include <fcntl.h>
-#endif
-
 #include <algorithm>
 #include <map>
 #include <memory>
@@ -92,7 +88,7 @@ class VSISparseFileHandle final : public VSIVirtualHandle
 /* ==================================================================== */
 /************************************************************************/
 
-class VSISparseFileFilesystemHandler : public VSIFilesystemHandler
+class VSISparseFileFilesystemHandler final : public VSIFilesystemHandler
 {
     std::map<GIntBig, int> oRecOpenCount{};
     CPL_DISALLOW_COPY_ASSIGN(VSISparseFileFilesystemHandler)
@@ -105,13 +101,9 @@ class VSISparseFileFilesystemHandler : public VSIFilesystemHandler
                       vsi_l_offset &nSparseFileOffset,
                       vsi_l_offset &nSparseFileSize);
 
-    // TODO(schwehr): Fix VSISparseFileFilesystemHandler::Stat to not need
-    // using.
-    using VSIFilesystemHandler::Open;
-
-    VSIVirtualHandle *Open(const char *pszFilename, const char *pszAccess,
-                           bool bSetError,
-                           CSLConstList /* papszOptions */) override;
+    VSIVirtualHandleUniquePtr Open(const char *pszFilename,
+                                   const char *pszAccess, bool bSetError,
+                                   CSLConstList /* papszOptions */) override;
     int Stat(const char *pszFilename, VSIStatBufL *pStatBuf,
              int nFlags) override;
     int Unlink(const char *pszFilename) override;
@@ -407,7 +399,7 @@ void VSISparseFileHandle::ClearErr()
 /*                                Open()                                */
 /************************************************************************/
 
-VSIVirtualHandle *VSISparseFileFilesystemHandler::Open(
+VSIVirtualHandleUniquePtr VSISparseFileFilesystemHandler::Open(
     const char *pszFilename, const char *pszAccess, bool /* bSetError */,
     CSLConstList /* papszOptions */)
 
@@ -430,10 +422,8 @@ VSIVirtualHandle *VSISparseFileFilesystemHandler::Open(
     /* -------------------------------------------------------------------- */
     /*      Does this file even exist?                                      */
     /* -------------------------------------------------------------------- */
-    VSILFILE *fp = VSIFOpenL(osSparseFilePath, "r");
-    if (fp == nullptr)
+    if (VSIFilesystemHandler::OpenStatic(osSparseFilePath, "rb") == nullptr)
         return nullptr;
-    CPL_IGNORE_RET_VAL(VSIFCloseL(fp));
 
     /* -------------------------------------------------------------------- */
     /*      Read the XML file.                                              */
@@ -446,7 +436,7 @@ VSIVirtualHandle *VSISparseFileFilesystemHandler::Open(
     /* -------------------------------------------------------------------- */
     /*      Setup the file handle on this file.                             */
     /* -------------------------------------------------------------------- */
-    VSISparseFileHandle *poHandle = new VSISparseFileHandle(this);
+    auto poHandle = std::make_unique<VSISparseFileHandle>(this);
 
     /* -------------------------------------------------------------------- */
     /*      Translate the desired fields out of the XML tree.               */
@@ -484,7 +474,7 @@ VSIVirtualHandle *VSISparseFileFilesystemHandler::Open(
         oRegion.byValue =
             static_cast<GByte>(atoi(CPLGetXMLValue(psRegion, "Value", "0")));
 
-        poHandle->aoRegions.push_back(oRegion);
+        poHandle->aoRegions.push_back(std::move(oRegion));
     }
 
     /* -------------------------------------------------------------------- */
@@ -505,7 +495,7 @@ VSIVirtualHandle *VSISparseFileFilesystemHandler::Open(
 
     CPLDestroyXMLNode(psXMLRoot);
 
-    return poHandle;
+    return VSIVirtualHandleUniquePtr(poHandle.release());
 }
 
 /************************************************************************/
@@ -516,9 +506,7 @@ int VSISparseFileFilesystemHandler::Stat(const char *pszFilename,
                                          VSIStatBufL *psStatBuf, int nFlags)
 
 {
-    // TODO(schwehr): Fix this so that the using statement is not needed.
-    // Will just adding the bool for bSetError be okay?
-    VSIVirtualHandle *poFile = Open(pszFilename, "r");
+    auto poFile = Open(pszFilename, "rb", false, nullptr);
 
     memset(psStatBuf, 0, sizeof(VSIStatBufL));
 
@@ -527,7 +515,6 @@ int VSISparseFileFilesystemHandler::Stat(const char *pszFilename,
 
     poFile->Seek(0, SEEK_END);
     const vsi_l_offset nLength = poFile->Tell();
-    delete poFile;
 
     const int nResult =
         VSIStatExL(pszFilename + strlen("/vsisparse/"), psStatBuf, nFlags);
